@@ -3,10 +3,10 @@
  *  Module    : tin.h
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2016-04-12
+ *  Updated   : 2018-11-27
  *  Notes     : #include files, #defines & struct's
  *
- * Copyright (c) 1997-2016 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
+ * Copyright (c) 1997-2019 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -79,7 +79,9 @@
 #define N_(Str) Str
 
 #if defined(ENABLE_NLS) && !defined(__BUILD__)
-#	include <libintl.h>
+#	ifdef HAVE_LIBINTL_H
+#		include <libintl.h>
+#	endif /* HAVE_LIBINTL_H */
 #	define _(Text)	gettext(Text)
 #else
 #	undef bindtextdomain
@@ -188,7 +190,6 @@ enum rc_state { RC_IGNORE, RC_CHECK, RC_UPGRADE, RC_DOWNGRADE, RC_ERROR };
 #	include <getopt.h>
 #endif /* HAVE_GETOPT_H */
 
-
 #if defined(ENABLE_LONG_ARTICLE_NUMBERS) && !defined(SMALL_MEMORY_MACHINE)
 /*
  * defines and typedefs for 64 bit article numbers
@@ -697,10 +698,9 @@ enum rc_state { RC_IGNORE, RC_CHECK, RC_UPGRADE, RC_DOWNGRADE, RC_ERROR };
 #define URL_REGEX	"\\b(?:https?|ftp|gopher)://(?:[^:@/\\s]*(?::[^:@/\\s]*)?@)?(?:(?:(?:[^\\W_](?:(?:-|[^\\W_]){0,61}(?<!---)[^\\W_])?|xn--[^\\W_](?:-(?!-)|[^\\W_]){1,57}[^\\W_])\\.)+[a-z]{2,14}\\.?|localhost|(?:(?:2[0-4]\\d|25[0-5]|[01]?\\d\\d?)\\.){3}(?:2[0-4]\\d|25[0-5]|[01]?\\d\\d?)|\\[(?:(?:[0-9A-F]{0,4}:){1,7}[0-9A-F]{1,4}|(?:[0-9A-F]{0,4}:){1,3}(?:(?:2[0-4]\\d|25[0-5]|[01]?\\d\\d?)\\.){3}(?:2[0-4]\\d|25[0-5]|[01]?\\d\\d?))\\])(?::\\d+)?(?(?=[^\\)\\]\\>\"\\s]*\\()(?:/[^\\]\\>\"\\s]*|$|(?=[)\\]\\>\"\\s]))|(?:/[^)\\]\\>\"\\s]*|$|(?=[)\\]\\>\"\\s])))"
 /*
  * case insensitive
- * TOFO: check against RFC 2368
+ * TOFO: check against RFC 6068
  */
-/* #define MAIL_REGEX	"\\b(?:mailto:(?:(?:[-\\w$.+!*'(),;/?:@&=]|(?:%[\\da-f]{2}))+))" */
-#define MAIL_REGEX	"\\b(?:mailto:(?:[-\\w$.+!*'(),;/?:@&=]|%[\\da-f]{2})+)"
+#define MAIL_REGEX	"\\b(?:mailto:(?:[-\\w$.+!*'(),;/?:@&=]|%[\\da-f]{2})+)(?<!\\))"
 /*
  * case insensitive
  * TODO: check against RFC 5538
@@ -852,6 +852,7 @@ enum rc_state { RC_IGNORE, RC_CHECK, RC_UPGRADE, RC_DOWNGRADE, RC_ERROR };
 
 #define NEWSRC_LINE	8192
 #define HEADER_LEN	1024
+#define IMF_LINE_LEN 998 /* RFC 5322 2.1.1 */
 
 #define TABLE_SIZE	1409
 
@@ -866,7 +867,7 @@ enum rc_state { RC_IGNORE, RC_CHECK, RC_UPGRADE, RC_DOWNGRADE, RC_ERROR };
 #endif /* !DEFAULT_ISO2ASC */
 
 #ifndef DEFAULT_COMMENT
-#	define DEFAULT_COMMENT	"> "	/* used when by follow-ups & replys */
+#	define DEFAULT_COMMENT	"> "	/* used when by follow-ups & replies */
 #endif /* !DEFAULT_COMMENT */
 #ifndef ART_MARK_UNREAD
 #	define ART_MARK_UNREAD	'+'	/* used to show that an art is unread */
@@ -884,7 +885,7 @@ enum rc_state { RC_IGNORE, RC_CHECK, RC_UPGRADE, RC_DOWNGRADE, RC_ERROR };
 #	define ART_MARK_READ	' '	/* used to show that an art was not read or seen */
 #endif /* !ART_MARK_READ */
 #ifndef ART_MARK_READ_SELECTED
-#	define ART_MARK_READ_SELECTED ':'	/* used to show that an read art is hot (kill_level >0) */
+#	define ART_MARK_READ_SELECTED ':'	/* used to show that a read art is hot (kill_level >0) */
 #endif /* !ART_MARK_READ_SELECTED */
 #ifndef ART_MARK_KILLED
 #	define ART_MARK_KILLED 'K'		/* art has been killed (kill_level >0) */
@@ -1006,7 +1007,7 @@ enum {
 #	define INDEX2SNUM(i)	((i) - currmenu->first)
 #endif /* !USE_CURSES */
 
-#define GROUP_MATCH(s1, pat, case)		(wildmat(s1, pat, case))
+#define GROUP_MATCH(s1, pat, case_s)		(wildmat(s1, pat, case_s))
 
 #define REGEX_FMT (tinrc.wildcard ? "%s" : "*%s*")
 
@@ -1033,7 +1034,7 @@ enum {
 #endif /* NNTP_ABLE */
 
 /*
- * Often used macro to point to the group we are currenty in
+ * Often used macro to point to the group we are currently in
  */
 #define CURR_GROUP	(active[my_group[selmenu.curr]])
 
@@ -1281,16 +1282,20 @@ enum {
 #ifdef assert
 #	undef assert
 #endif /* assert */
-#ifdef CPP_DOES_EXPAND
-#	define assert(p)	if(! (p)) asfail(__FILE__, __LINE__, #p); else (void)0;
+#ifdef NDEBUG
+#	define assert(p)        ((void) 0)
 #else
-#	define assert(p)	if(! (p)) asfail(__FILE__, __LINE__, "p"); else (void)0;
-#endif /* CPP_DOES_EXPAND */
+#	ifdef CPP_DOES_EXPAND
+#		define assert(p)	if(!(p)) asfail(__FILE__, __LINE__, #p); else (void) 0;
+#	else
+#		define assert(p)	if(!(p)) asfail(__FILE__, __LINE__, "p"); else (void) 0;
+#	endif /* CPP_DOES_EXPAND */
+#endif /* NDEBUG */
 
 #define ESC	27
 
 /*
- * filter entrys expire after DEFAULT_FILTER_DAYS
+ * filter entries expire after DEFAULT_FILTER_DAYS
  */
 #define DEFAULT_FILTER_DAYS		28
 
@@ -1378,7 +1383,7 @@ enum {
 #		else
 #			if defined(HAVE_LIBIDN) && defined(HAVE_STRINGPREP_H)
 #				define HAVE_UNICODE_NORMALIZATION 1
-#			endif /* HAVE_LIBIDN */
+#			endif /* HAVE_LIBIDN && HAVE_STRINGPREP_H */
 #		endif /* HAVE_LIBUNISTRING */
 #	endif /* HAVE_LIBICUUC */
 #endif /* MULTIBYTE_ABLE && !NO_LOCALE */
@@ -1394,6 +1399,9 @@ enum {
 	NORMALIZE_NFKD = 2,
 	NORMALIZE_NFC = 3,
 	NORMALIZE_NFD = 4
+#ifdef HAVE_UNICODE_UNORM2_H
+	,NORMALIZE_NFKC_CF = 5
+#endif /* HAVE_UNICODE_UNORM2_H */
 #		define DEFAULT_NORMALIZE NORMALIZE_NFC
 #	else
 	NORMALIZE_NFKC = 1
@@ -1406,9 +1414,13 @@ enum {
 #	ifdef HAVE_UNICODE_USTRING_H
 #		include <unicode/ustring.h>
 #	endif /* HAVE_UNICODE_USTRING_H */
-#	ifdef HAVE_UNICODE_UNORM_H
-#		include <unicode/unorm.h>
-#	endif /* HAVE_UNICODE_UNORM_H */
+#	ifdef HAVE_UNICODE_UNORM2_H
+#		include <unicode/unorm2.h>
+#	else
+#		ifdef HAVE_UNICODE_UNORM_H
+#			include <unicode/unorm.h>
+#		endif /* HAVE_UNICODE_UNORM_H */
+#	endif /* HAVE_UNICODE_UNORM2_H */
 #	ifdef HAVE_UNICODE_UIDNA_H
 #		include <unicode/uidna.h>
 #	endif /* HAVE_UNICODE_UIDNA_H */
@@ -1492,6 +1504,7 @@ struct t_article {
 	int gnksa_code;			/* From: line from mail header (GNKSA error code) */
 	time_t date;			/* Date: line from header in seconds */
 	char *xref;			/* Xref: cross posted article reference line */
+	char *path;			/* Path: line */
 	/* NB: The msgid and refs are only retained until the reference tree is built */
 	char *msgid;			/* Message-ID: unique message identifier */
 	char *refs;			/* References: article reference id's */
@@ -1512,6 +1525,20 @@ struct t_article {
 	t_bool keep_in_base:1;	/* TRUE = keep (read) article in base[] (show_only_unread_arts) */
 };
 
+
+#ifdef NNTP_ABLE
+/*
+ * struct t_article_range - holds ranges of article numbers to perform actions on parts of arts[]
+ */
+struct t_article_range {
+	t_artnum start;
+	t_artnum end;
+	t_artnum cnt;
+	struct t_article_range *next;
+};
+#endif /* NNTP_ABLE */
+
+
 /*
  * struct t_newsheader - holds an array of which news headers to [not] display
  */
@@ -1843,6 +1870,7 @@ struct t_filter {
 	int gnksa_num;			/* GNKSA code */
 	int score;			/* score to give if rule matches */
 	char *xref;			/* groups in xref line */
+	char *path;			/* server in path line */
 	time_t time;			/* expire time in seconds */
 	struct t_filter *next;		/* next rule valid in group */
 	unsigned int inscope:4;		/* if group matches scope e.g. 'comp.os.*' */
@@ -2374,6 +2402,33 @@ extern struct tm *localtime(time_t *);
 #	include <gsasl.h>
 #endif /* USE_SASL */
 
+/*
+ * adapted from ncurses curses.priv.h:
+ * If we have va_copy(), use it for assigning va_list's.
+ */
+#if defined(HAVE___VA_COPY)
+#	define begin_va_copy(dst,src)	__va_copy(dst, src)
+#	define end_va_copy(dst)	va_end(dst)
+#else
+#	if defined(va_copy) || defined(HAVE_VA_COPY)
+#		define begin_va_copy(dst,src)	va_copy(dst, src)
+#		define end_va_copy(dst)	va_end(dst)
+#	else
+#		if defined(HAVE___BUILTIN_VA_COPY)
+#			define begin_va_copy(dst,src)	__builtin_va_copy(dst, src)
+#			define end_va_copy(dst)	va_end(dst)
+#		else
+#			if defined(ARRAY_VA_LIST)
+#				define begin_va_copy(dst,src)	*(dst) = *(src)
+#				define end_va_copy(dst)	/* nothing */
+#			else
+#				define begin_va_copy(dst,src)	(dst) = (src)
+#				define end_va_copy(dst)	/* nothing */
+#			endif /* ARRAY_VA_LIST */
+#		endif /* HAVE___BUILTIN_VA_COPY */
+#	endif /* va_copy || HAVE_VA_COPY */
+#endif /* HAVE___VA_COPY */
+
 /* snprintf(), vsnprintf() */
 #ifndef HAVE_SNPRINTF
 #	define snprintf	plp_snprintf
