@@ -3,10 +3,10 @@
  *  Module    : tinrc.h
  *  Author    : Jason Faultless <jason@altarstone.com>
  *  Created   : 1999-04-13
- *  Updated   : 2016-04-17
+ *  Updated   : 2017-08-13
  *  Notes     :
  *
- * Copyright (c) 1999-2016 Jason Faultless <jason@altarstone.com>
+ * Copyright (c) 1999-2019 Jason Faultless <jason@altarstone.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -212,7 +212,7 @@ struct t_config {
 	t_bool info_in_last_line;
 	t_bool inverse_okay;
 	t_bool keep_dead_articles;			/* keep all dead articles in dead.articles */
-	char posted_articles_file[LEN];		/* if set, file in which to keep posted articles */
+	char posted_articles_file[PATH_LEN];		/* if set, file in which to keep posted articles */
 	t_bool mail_8bit_header;			/* allow 8bit chars. in header of mail message */
 	t_bool mark_ignore_tags;			/* Ignore tags for GROUP_MARK_THREAD_READ/THREAD_MARK_ARTICLE_READ */
 	t_bool mark_saved_read;				/* mark saved article/thread as read */
@@ -247,6 +247,9 @@ struct t_config {
 		t_bool extquote_handling;		/* Detection of quoted text from external sources */
 #	endif /* HAVE_COLOR */
 	char inews_prog[PATH_LEN];
+#ifdef USE_CANLOCK
+		int cancel_lock_algo;			/* algorithm used for Cancel-Lock/Cancel-Key */
+#endif /* USE_CANLOCK */
 	int interactive_mailer;			/* invoke user's mailreader */
 	t_bool use_mouse;					/* enables/disables mouse support under xterm */
 #	ifdef HAVE_KEYPAD
@@ -260,7 +263,7 @@ struct t_config {
 	t_bool default_filter_select_case;
 	t_bool default_filter_select_expire;
 #	ifdef XFACE_ABLE
-		t_bool use_slrnface;			/* Use the slrnface programme to display 'X-Face:'s */
+		t_bool use_slrnface;			/* Use the slrnface program to display 'X-Face:'s */
 #	endif /* XFACE_ABLE */
 	t_bool default_filter_select_global;
 	char select_format[LEN];		/* format string for the selection level */
