@@ -3,10 +3,10 @@
  *  Module    : save.c
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2016-03-26
+ *  Updated   : 2018-11-23
  *  Notes     :
  *
- * Copyright (c) 1991-2016 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
+ * Copyright (c) 1991-2019 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -213,7 +213,7 @@ check_start_save_any_news(
 			if (function == SAVE_ANY_NEWS) {
 				char tmp[PATH_LEN];
 
-				if (!strfpath(cmdline.args & CMDLINE_SAVEDIR ? cmdline.savedir : tinrc.savedir, tmp, sizeof(tmp), group, FALSE))
+				if (!strfpath((cmdline.args & CMDLINE_SAVEDIR) ? cmdline.savedir : tinrc.savedir, tmp, sizeof(tmp), group, FALSE))
 					joinpath(tmp, sizeof(tmp), homedir, DEFAULT_SAVEDIR);
 
 				make_group_path(group->name, group_path);
@@ -493,7 +493,7 @@ save_and_process_art(
 		const char *partprefix;
 		char *ptr;
 		char archpath[PATH_LEN];
-		char filename[NAME_LEN];
+		char filename[NAME_LEN + 1];
 
 		/*
 		 * We need either a part or a patch number, part takes precedence
@@ -573,7 +573,7 @@ save_and_process_art(
 
 	/*
 	 * Extract/view parts from multipart articles if required
-	 * libuu does this as part of it's own processing
+	 * libuu does this as part of its own processing
 	 */
 #ifndef HAVE_LIBUU
 	if (post_process) {
@@ -648,6 +648,7 @@ generate_filename(
 	snprintf(buf, buflen, "%s-%03d.%s", SAVEFILE_PREFIX, seqno++, suffix);
 }
 
+
 /*
  * Generate /save/to/path name.
  *
@@ -663,7 +664,7 @@ generate_savepath(
 	const char *name;
 	t_bool mbox;
 
-	savepath = my_malloc(PATH_LEN + 1);
+	savepath = my_malloc(PATH_LEN);
 	/*
 	 * Get the filename to save to in 'savepath'
 	 */
@@ -720,7 +721,7 @@ expand_save_filename(
 	base_name(buf_path, base_filename);
 
 	/* Build default path to save to */
-	if (!(ret = strfpath(cmdline.args & CMDLINE_SAVEDIR ? cmdline.savedir : curr_group->attribute->savedir, buf, sizeof(buf), curr_group, FALSE)))
+	if (!(ret = strfpath((cmdline.args & CMDLINE_SAVEDIR) ? cmdline.savedir : curr_group->attribute->savedir, buf, sizeof(buf), curr_group, FALSE)))
 		joinpath(buf, sizeof(buf), homedir, DEFAULT_SAVEDIR);
 
 	/* Join path and filename */
@@ -881,8 +882,6 @@ post_process_uud(
 	my_printf(_(txt_libuu_saved), count, num_save, errors, PLURAL(errors, txt_error));
 	my_printf(cCRLF);
 	UUCleanUp();
-
-	return;
 }
 
 #else
@@ -949,6 +948,7 @@ post_process_uud(
 						filename = strrchr(path, DIRSEP) + 1;	/* ptr to filename portion */
 						if ((fp_out = fopen(path, "w")) == NULL) {
 							perror_message(_(txt_cannot_open), path);
+							fclose(fp_in);
 							return;
 						}
 						state = MIDDLE;
@@ -957,7 +957,7 @@ post_process_uud(
 
 				case MIDDLE:
 					/*
-					 * TODO: replace hardcoded length check (uue lines are not
+					 * TODO: replace hard coded length check (uue lines are not
 					 *       required to be 60 chars long (45 encoded chars)
 					 *       ('M' == 60 * 3 / 4 + ' ' == 77))
 					 */
@@ -1141,7 +1141,6 @@ uudecode_line(
 			}
 		}
 	}
-	return;
 }
 
 
@@ -1171,7 +1170,7 @@ post_process_sh(
 		if ((fp_in = fopen(save[i].path, "r")) == NULL)
 			continue;
 
-		wait_message(1, _(txt_extracting_shar), save[i].path);
+		wait_message(0, _(txt_extracting_shar), save[i].path);
 
 		while (fgets(buf, (int) sizeof(buf), fp_in) != NULL) {
 			/* find #!/bin/sh style patterns */
@@ -1184,8 +1183,10 @@ post_process_sh(
 		}
 		fclose(fp_in);
 
-		if (fp_out == NULL)			/* Didn't extract any shar */
+		if (fp_out == NULL) {			/* Didn't extract any shar */
+			my_fputs(cCRLF, stdout);
 			continue;
+		}
 
 		fclose(fp_out);
 		fp_out = NULL;
@@ -1199,7 +1200,6 @@ post_process_sh(
 #endif /* !M_UNIX */
 		unlink(file_out);
 	}
-	return;
 }
 
 
@@ -1837,7 +1837,7 @@ build_attachment_line(
 #endif /* USE_CURSES */
 
 	part = get_part(i);
-	namelen = strwidth(_(txt_attachment_no_name));
+	namelen = MIN(cCOLS - 13 - info_len - 8, strwidth(_(txt_attachment_no_name)));
 	tagged = get_tagged(i);
 
 	if (!(name = get_filename(part->params))) {
@@ -2051,9 +2051,9 @@ tag_pattern(
 		FreeIfNeeded(cache.re);
 		FreeIfNeeded(cache.extra);
 	}
-	return;
 }
 
+
 static int
 get_tagged(
 	int n)
@@ -2263,7 +2263,7 @@ process_part(
 	const char *savepath,
 	enum action what)
 {
-	FILE *infile = NULL;
+	FILE *infile;
 	char buf[2048], buf2[2048];
 	int count;
 	int i, line_count;
